@@ -11,3 +11,9 @@ def proper_title(text):
     """ Like built-in |title filter but leaves existing caps alone, eg.
     'I work for the FBI' -> 'I Work For The FBI'. """
     return pattern.sub(cap, text + u'') #+ u'' to handle proxy objects
+
+@register.filter
+def transliterate(text, country_code):
+    from langacore.kit.i18n import translit
+    
+    return translit.any(country_code, text)
